#!/usr/bin/env node

'use strict';

const os        = require('os');
const cli       = require('cli').enable('version');
const nexrender = require('./index.js');

cli.parse({
    'aerender':     [false, 'PATH to aerender binary', 'path'],
    'api-server':   ['s', 'Start api server'],
    'renderer':     ['r', 'Start renderer'],
    'host':         ['h', 'Remote HOST:PORT to connect', 'host', 'localhost:3000'],
    'port':         ['p', 'Listen on port', 'port', 3000],
    'version':      ['v', 'Get version']
});

// Usage: 
// nexrender --renderer --host=localhost:3000 --aerender="/Applications/Adobe After Effects CC 2015/aerender"
//           -rh localhost:3000 --aerender="/Applications/Adobe After Effects CC 2015/aerender"
// nexrender --api-server --port=3000
//           -sp 3000

cli.main(function(args, options) {

    if (options.version) {
        return console.log('nexrender version:', nexrender.version)
    }

    if (options['api-server']) {
        nexrender.server.start(options.port);
    }

    if (options['renderer']) {
        if (['darwin', 'win32', 'win64'].indexOf( os.platform() ) == -1) {
            console.warn('[error] you might be considering to run renderer on officialy supported platform');
        }

        if (!options.aerender) {
            return console.error('[error] provide --aerender=PATH for aerender binary file');
        }

        process.env.AE_BINARY = options.aerender;

        let host = options.host.split(':');

        nexrender.renderer.start( host[0], host[1] );
    }
});
