'use strict';

const mkdirp      = require('mkdirp');
const path        = require('path');
const fs          = require('fs-extra');

const TEMPLATES_DIRECTORY   = process.env.TEMPLATES_DIRECTORY   || "templates";
const TEMP_DIRECTORY        = process.env.TEMP_DIRECTORY        || "temp";

/**
 * This task creates working directory for current project
 */
module.exports = function(project) {
    return new Promise((resolve, reject) => {

        console.log(`[${project.uid}] setting up project...`);

        // setup project's workpath
        project.workpath   = path.join(TEMP_DIRECTORY,      project.uid);

        // set template path && projectname
        let templatepath   = path.join(TEMPLATES_DIRECTORY, project.template);
        let workingProject = path.join(project.workpath,    project.template);

        // create, if it does not exists
        mkdirp.sync(project.workpath);

        // if project is custom - dont copy (it must be downloaded)
        if (project.type && project.type === 'custom') {
            return resolve(project);
        }

        // copy project file
        fs.copy(templatepath, workingProject, (err) => {
            return (err) ? reject(err) : resolve(project);
        });
    });
};
